import { Queue as BullMQQueue, Job as BullMQJob } from 'bullmq';
import { Job, Queue, QueueProvider } from './queue';
import type { JobId, JobStatus, JobStatusClean, JobCounts, JobLogs, GlobalJobCompletionCb, QueueConfig } from './queue';
import type { Maybe } from './typings/utils';
export declare class BullMQJobAdapter extends Job {
    private _job;
    private _queue;
    constructor(_job: BullMQJob, _queue: Queue);
    get rawJob(): BullMQJob;
    get queue(): Queue;
    get id(): JobId;
    get name(): string;
    get data(): any;
    get returnvalue(): unknown;
    get progress(): string;
    get attemptsMade(): number;
    get failedReason(): string | undefined;
    get stacktrace(): string[];
    get opts(): import("bullmq").JobsOptions;
    get processedOn(): Maybe<number>;
    get finishedOn(): Maybe<number>;
    get timestamp(): Maybe<number>;
    getState(): Promise<JobStatus>;
    moveToCompleted(returnValue: any): Promise<any>;
    moveToFailed(reason: Error): Promise<void>;
    promote(): Promise<void>;
    discard(): Promise<void>;
    update(data: any): Promise<void>;
    retry(): Promise<void>;
    remove(): Promise<void>;
    log(row: string): Promise<void>;
}
export declare class BullMQAdapter extends Queue {
    private _queue;
    private _queueEvents?;
    private _globalJobCompletionCb?;
    private _id;
    constructor(_queue: BullMQQueue, config?: QueueConfig);
    get provider(): QueueProvider;
    private get queueEvents();
    get client(): Promise<import("bullmq").RedisClient>;
    get id(): string;
    get name(): string;
    get token(): string;
    set onGlobalJobCompletion(callback: GlobalJobCompletionCb);
    toKey(queueType: string): string;
    count(): Promise<number>;
    add(name: string, data: any, opts?: any): Promise<Job>;
    pause(): Promise<void>;
    resume(): Promise<void>;
    clean(grace: number, status?: JobStatusClean, limit?: number): Promise<JobId[]>;
    empty(): Promise<void>;
    isPaused(): Promise<boolean>;
    getJob(id: JobId): Promise<Maybe<Job>>;
    jobFromJSON(json: any, jobId: JobId): Job;
    getJobs(types: JobStatus | JobStatus[], start?: number, end?: number, asc?: boolean): Promise<Job[]>;
    getJobCounts(): Promise<JobCounts>;
    getActiveCount(): Promise<number>;
    getCompletedCount(): Promise<number>;
    getFailedCount(): Promise<number>;
    getDelayedCount(): Promise<number>;
    getWaitingCount(): Promise<number>;
    getPausedCount(): Promise<number>;
    removeJobs(): Promise<void>;
    getJobLogs(jobId: JobId): Promise<JobLogs>;
    close(): Promise<void>;
    private normalizeJob;
}
