import { DataSource } from 'apollo-datasource';
import { OrderEnum } from '../../../typings/gql';
import redisInfo from 'redis-info';
import type { Queue, JobStatus, JobId, JobCounts, Job } from '../../../queue';
import type { CreateJobInput, MutationCleanQueueArgs, MutationCloseQueueArgs, MutationDiscardJobArgs, MutationEmptyQueueArgs, MutationLogArgs, MutationMoveJobToCompletedArgs, MutationMoveJobToFailedArgs, MutationPromoteJobArgs, MutationRemoveJobArgs, MutationRemoveJobsArgs, MutationRemoveJobsByPatternArgs, MutationResumeQueueArgs, MutationRetryJobArgs, MutationRetryJobsArgs, MutationUpdateJobDataArgs } from '../../../typings/gql';
import type { Maybe } from '../../../typings/utils';
declare type Config = {
    textSearchScanCount?: number;
};
export declare class BullDataSource extends DataSource {
    private _queues;
    private _queuesMap;
    private _config;
    constructor(_queues: Queue[], _queuesMap: Map<string, Queue>, _config: Config);
    getQueueById(id: string, throwIfNotFound?: boolean): Queue | undefined;
    getQueues(): Queue[];
    getQueueJobs({ queue, limit, offset, status, id, ids, order, dataSearch, }: {
        limit?: number;
        offset?: number;
        dataSearch?: string;
        id?: string;
        order?: OrderEnum;
        ids?: string[];
        status?: JobStatus;
        queue: string;
    }): Promise<Job[]>;
    getJob(queueId: string, id: JobId, throwIfNotFound?: boolean): Promise<Maybe<Job>>;
    extractJobProcessingTime(job: Job): number;
    getQueueJobsCounts(id: string): Promise<Maybe<JobCounts>>;
    getQueueFailedCount(id: string): Promise<Maybe<number>>;
    getQueueCompletedCount(id: string): Promise<Maybe<number>>;
    getQueueDelayedCount(id: string): Promise<Maybe<number>>;
    getQueueActiveCount(id: string): Promise<Maybe<number>>;
    getQueueWaitingCount(id: string): Promise<Maybe<number>>;
    getQueuePausedCount(id: string): Promise<Maybe<number>>;
    getQueueWaitingOrDelayedJobsCount(id: string): Promise<Maybe<number>>;
    getRedisInfo(): Promise<redisInfo.RedisInfo | null>;
    createJob({ queue: queueId, name, data, options, }: CreateJobInput): Promise<Job>;
    removeJobsByPattern(args: MutationRemoveJobsByPatternArgs): Promise<boolean>;
    pauseQueue(id: string): Promise<Queue>;
    cleanQueue(args: MutationCleanQueueArgs): Promise<string[]>;
    emptyQueue(args: MutationEmptyQueueArgs): Promise<Queue>;
    closeQueue(args: MutationCloseQueueArgs): Promise<Queue>;
    resumeQueue(args: MutationResumeQueueArgs): Promise<Queue>;
    promoteJob(args: MutationPromoteJobArgs): Promise<Maybe<Job>>;
    discardJob(args: MutationDiscardJobArgs): Promise<Maybe<Job>>;
    updateJobData(args: MutationUpdateJobDataArgs): Promise<Maybe<Job>>;
    createJobLog(args: MutationLogArgs): Promise<Maybe<Job>>;
    retryJob(args: MutationRetryJobArgs): Promise<Maybe<Job>>;
    retryJobs(args: MutationRetryJobsArgs): Promise<Maybe<Job>[]>;
    removeJobById(args: MutationRemoveJobArgs): Promise<Maybe<Job>>;
    removeJobs(args: MutationRemoveJobsArgs): Promise<Maybe<Job>[]>;
    moveJobToCompleted(args: MutationMoveJobToCompletedArgs): Promise<Maybe<Job>>;
    moveJobToFailed(args: MutationMoveJobToFailedArgs): Promise<Maybe<Job>>;
    private _filterJobs;
    private _throwInternalError;
    private _throwQueueNotFound;
    private _throwJobNotFound;
}
export {};
